@@ -1,10 +1,8 @@
 package Moonshine::Magic;
 
-use 5.006;
 use strict;
 use warnings;
 
-use UNIVERSAL::Object;
 use BEGIN::Lift;
 use Moonshine::Element;
 
@@ -14,11 +12,11 @@ Moonshine::Magic - d[ o_0 ]b - has, extends, lazy_components
 
 =head1 VERSION
 
-Version 0.04
+Version 0.05
 
 =cut
 
-our $VERSION = '0.04';
+our $VERSION = '0.05';
 
 =head1 SYNOPSIS
 
@@ -51,53 +49,50 @@ sub import {
     my $caller = caller;
 
     BEGIN::Lift::install(
-        ( $caller, 'extends' ) => sub {
+        ($caller, 'extends') => sub {
             no strict 'refs';
             @{"${caller}::ISA"} = @_;
         }
     );
 
     BEGIN::Lift::install(
-        ( $caller, 'has' ) => sub {
+        ($caller, 'has') => sub {
             my %args = @_;
             no strict 'refs';
             no warnings 'once';
             %{"${caller}::HAS"} = %args;
-            for my $arg ( keys %args ) {
+            for my $arg (keys %args) {
                 *{"${caller}::${arg}"} = sub { return $args{$arg}->(); };
             }
         }
     );
 
     BEGIN::Lift::install(
-        ( $caller, 'lazy_components' ) => sub {
-            my @lazy_components = @_;
+        ($caller, 'lazy_components') => sub {
+	        my @lazy_components = @_;
             no strict 'refs';
             no warnings 'once';
             for my $component (@lazy_components) {
-                *{"${caller}::${component}"} = sub {
-                    my $self = shift;
-
-                    my ( $base_args, $build_args ) = ();
-                    if ( $self->can('validate_build') ) {
-                        ( $base_args, $build_args ) = $self->validate_build(
-                            {
-                                params => $_[0] // {},
-                                spec => {
-                                    tag  => { default => $component },
-                                    data => 0,
-                                    ( $_[1] ? %{ $_[1] } : () )
-                                }
+		        *{"${caller}::${component}"} = sub {
+			        my $self = shift;
+                   
+                    my ($base_args, $build_args) = ();
+                    if ($self->can('validate_build')) {
+                        ( $base_args, $build_args ) = $self->validate_build({
+                            params => $_[0] // {},
+                            spec => {
+                                tag  => { default => $component },
+                                data => 0,
+                                ( $_[1] ? %{ $_[1] } : () )
                             }
-                        );
-                    }
-                    else {
-                        $base_args = { tag => $component, %{ $_[0] } };
+                        });
+                    } else {
+                        $base_args = { tag => $component, %{ $_[0] } }; 
                     }
 
                     return Moonshine::Element->new($base_args);
-                  }
-            }
+                }
+	        }
         }
     );
 }
@@ -187,4 +182,4 @@ EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 
 =cut
 
-1;    # End of Moonshine::Magic
+1; # End of Moonshine::Magic
